/**
 * The class Book manages title, author and pages data fields.
 * 
 * @author Prof. Struck 
 * @version Version 1
 */
public class Book
{
    private String title;   // Title of the book
    private String author;   // Author of the book
    private int pages;       // The number of pages in the book

    /**
     * Constructor sets the title and author to empty strings, and number of pages to zero.
     */
    public Book()
    {
        this("", "", 0);
    }

    /**
     * Constructor sets the title and author to the values of the parameters.
     * 
     * @param title the title of the book
     * @param author the author of the book
     * @param pages the number of pages in the book
     */
    public Book(String title, String author, int pages)
    {
        setTitle(title);
        setAuthor(author);
        setPages(pages);
    }

    /**
     * Mutator method that updates the value of the title instance variable.
     * 
     * @param title the title of the book
     */
    public void setTitle(String title)
    {
        this.title = title;
    }

    /**
     * Mutator method that updates the value of the author instance variable.
     * 
     * @param author the author of the book
     */
    public void setAuthor(String author)
    {
        this.author = author;
    }
    
    /**
     * Mutator method the updates the number of pages in the book.
     * 
     * @param pages the number of pages in the book
     */
    public void setPages(int pages)
    {
        if (pages > 0)
        {
            this.pages = pages;
        }
    }

    /**
     * Accessor method that returns the value of the title instance variable.
     * 
     * @return the title of the book
     */
    public String getTitle()
    {
        return title;
    }

    /**
     * Accessor method that returns the value of the author instance variable.
     * 
     * @return the author of the book
     */
    public String getAuthor()
    {
        return author;
    }
    
    /**
     * Accessor method that returns the number of pages in the book.
     * 
     * @return the number of pages in the book
     */
    public int getPages()
    {
        return pages;
    }
    
    /**
     * Returns the Book information with title, author and pages.
     * 
     * @return the title, author and pages with labels
     */
    public String toString()
    {
        return "Title: " + getTitle()
             + "\nAuthor: " + getAuthor()
             + "\nPages :" + getPages();
    }
}
